classdef CAmpSetter < CPanel
    %CAMPSETTER NiHu.Lab panel for adjusting preamp amplification
    %
    % See also: CAmplifier, CPanel
    
    properties (SetAccess = immutable)
        Channels    % handle to CChannel array
        Amp         % handle to CAmplifier object
    end
    
    methods
        function obj = CAmpSetter(parent, amp, channels)
            obj = obj@CPanel(parent, amp.Name);
            obj.Amp = amp;
            obj.Channels = channels(cell2mat({channels.isSelected}));
            obj.InitPanel();
        end
    end
    
    methods (Static)
        function PushAmpChannel(src, AmpChannel)
            %PUSHAMPCHANNEL Push the NEXT button on an amplifier
            AmpChannel.PushButton();
            set(src, 'String', AmpChannel.Amplification)
        end
    end
    
    methods (Access = private)
        function InitPanel(obj)
            nCh = length(obj.Channels);
            
            ChNum = zeros(nCh,1);
            for iCh = 1 : nCh
                if obj.Channels(iCh).AmpCh.Amplifier == obj.Amp
                    ChNum(iCh) = obj.Channels(iCh).AmpCh.ChNum;
                end
            end
            
            Layout = cell(1,nCh);
            h = zeros(1,obj.Amp.NumChannels);
            for iCh = 1 : obj.Amp.NumChannels
                t = uicontrol('parent', obj.hPanel, 'style', 'text', ...
                    'String', num2str(iCh),...
                    'FontSize', 7, 'ForegroundColor', [.4 .4 1]);
                set(t, 'position', get(t, 'extent'));
                h(iCh) = uicontrol('parent', obj.hPanel, ...
                    'Style', 'PushButton', 'units', 'pixels', ...
                    'KeyPressFcn', @(src,event)GuiLayout.CloseToEscapeCallback(event), ...
                    'position', [0 0 25 20], 'String', 'x', 'Enable', 'off');
                Layout{iCh} = {{{t, [0 0]};{h(iCh), [0 0]}}, [0 0]};
            end
            
            for iCh = 1 : nCh
                if ChNum(iCh) == 0
                    continue
                end
                set(h(ChNum(iCh)), 'Enable', 'on', ...
                    'String', num2str(obj.Channels(iCh).AmpCh.Amplification), ...
                    'ToolTipString', obj.Channels(iCh).Name, ...
                    'Callback', @(src,event)CAmpSetter.PushAmpChannel(src, obj.Channels(iCh).AmpCh));
            end
            
            GuiLayout.ApplyLayout(obj.hPanel, Layout);
        end
    end
end
