classdef CReferenceSelectView < CGuiView & CBlockablePanel
    %CREFERENCESELECTVIEW View class of CReferenceSelect
    
    properties (Access = private)
        hFileName   % handle where the file name is stored
        hDirName
        hClear
        hActive 
        hChannel
    end
    
    methods
        % Constructor
        function obj = CReferenceSelectView(parent, hData)
            obj = obj@CBlockablePanel(parent, 'REFERENCE_SELECT_PANEL');
            obj = obj@CGuiView(hData, {'FileName', 'Directory'});
            obj.InitObject();
            obj.refresh();
        end % of Constructor
        
        % Refresh the object
        function refresh(obj)
            set(obj.hFileName, 'String', obj.hData.FileName);
            set(obj.hDirName, 'String', obj.hData.Directory);
            % Update the status of refence object
            if obj.hData.IsFileChosen
                set(obj.hChannel, 'enable', 'on', ...
                    'String', obj.hData.ChannelNames(), ...
                    'Value', obj.hData.ChInd);
                set(obj.hActive, 'enable', 'on');
                set(obj.hClear, 'enable', 'on');
            else
                set(obj.hChannel, 'enable', 'ofF', ...
                    'String', {'No file has been selected yet.'});
                set(obj.hActive, 'enable', 'off');
                set(obj.hClear, 'enable', 'off');
            end
            
            if obj.hData.IsActive
                set(obj.hActive, 'String', 'ON', 'Value', 1);
            else
                set(obj.hActive, 'String', 'OFF', 'Value', 0);
            end
        end
        
        % FileSelect
        function FileSelect(obj)
            % TODO: this is debug only
            disp('CReferenceSelectView: FileSelect');
            % Open file select dialog
            [filename, pathname] = uigetfile( ...
                {'*.mat','MAT-files (*.mat)'; ...
                 '*.*',  'All Files (*.*)'}, ...
                'Select reference file');
            % Pass file to reference select module
            result = obj.hData.LoadFile(pathname, filename);
            % TODO handle results
            switch result
                % Alles hu
                case 0
                    obj.refresh();
            end
        end % of FileSelect method
        
        % SelectChannel
        function SelectChannel(obj)
            obj.hData.SelectChannel(get(obj.hChannel, 'Value'));
        end
        
        function ToggleActive(obj)
            obj.hData.ToggleActive;
            obj.refresh();
        end
        
        % ClearReference
        function ClearReference(obj)
            % TODO: this is debug only
            disp('CReferenceSelectView: ClearReference');
            obj.hData.ClearFile();
            obj.refresh();
        end
        
        
%         function FileCallback(obj)
%             obj.hData.FileName = get(obj.hFileName, 'String');
%             obj.hData.NextAvailable();
%         end
    end % of Public methods
    
    methods (Access = 'private')
        function InitObject(obj)
            % File name display
            obj.hFileName = uicontrol('Parent', obj.hPanel, ...
                'Style', 'Edit',...
                'units', 'pixels', ...
                'Callback', @(src,event)FileCallback(obj), ...
                'HorizontalAlignment', 'left');
            % Directory name display (needed?)
            obj.hDirName = uicontrol('Parent', obj.hPanel, ...
                'Style', 'Edit',...
                'units', 'pixels', ...
                'enable', 'inactive', ...
                'HorizontalAlignment', 'left');
            % File select button
            im = importdata([matlabroot, '/toolbox/matlab/icons/foldericon.gif']);
            butDir = uicontrol('Parent', obj.hPanel, 'Style', 'pushButton',...
                'String', '',...
                'CData', ind2rgb(im.cdata, im.colormap), ...
                'ToolTipStr', CBabel.getInstance().getText('SELECT_DIRECTORY'), ...
                'Callback', @(src,event)FileSelect(obj), ...
                'Position', [0, 0, CSetupClass.itemHeight, CSetupClass.itemHeight]);
            % Clear button
            % TODO: find suitable icon for reference clear
            obj.hClear =  uicontrol('Parent', obj.hPanel, 'Style', 'pushButton',...
                'String', 'X',...
                'FontWeight', 'bold', ...
                'ForeGroundColor', 'r', ...
                'ToolTipStr', CBabel.getInstance().getText('CLEAR_REFERENCE'), ...
                'Callback', @(src,event)ClearReference(obj), ...
                'Position', [0, 0, CSetupClass.itemHeight, CSetupClass.itemHeight]);
            % Reference ON / OFF indicator
            obj.hActive = uicontrol('Parent', obj.hPanel, 'Style', 'toggleButton',...
                'String', 'OFF', ...
                'ToolTipStr', CBabel.getInstance().getText('CHANGE_REFERENCE_ACTIVE'), ...
                'Callback', @(src,event)ToggleActive(obj), ...
                'FontWeight', 'bold', ...
                'Position', [0, 0, 2*CSetupClass.itemHeight, CSetupClass.itemHeight]);
            % List for name of the channel
            obj.hChannel = uicontrol('Parent', obj.hPanel, 'Style', 'popupMenu', ...
                'String', {'No file has been selected yet'}, ...
                'Callback', @(src, event)SelectChannel(obj), ...
                'units', 'pixels', ...
                'enable', 'off', ...
                'HorizontalAlignment', 'left');
            % Create layout
            l1 = {{obj.hFileName, [-1 0]}, {butDir, [0 0]}, {obj.hClear, [0 0]}, {obj.hActive, [0 0]}};
            l2 = {{obj.hDirName, [-1 0]}};
            l3 = {{obj.hChannel, [-1 0]}};
            % Apply the layout
            GuiLayout.ApplyLayout(obj.hPanel, {{l1, [-1 0]}; {l2, [-1 0]}; {l3, [-1 0]}});
        end % of InitObject Method
    end
end