classdef CStreamer < handle
    %CSTREAMER Class to stream data to a binary file
    
    properties (Constant)
        MaximalBinaryFileSize = 100e6
    end
    
    properties (Access = private)
        FileName
        fidData     % file pointer to stream file
        tStart
        nCh
        Twits
        byteCounter
        fileCounter
    end % of provate properties
    
    methods
        function Initialize(obj, FileName, channels, AcqSetup) %#ok<INUSD>
            % get only used channels
            ChSetup = channels(cell2mat({channels.isSelected}));
            
            obj.FileName = FileName;
            obj.nCh = length(ChSetup);
            obj.tStart = tic;
            obj.Twits = cell(0,2);
            save(sprintf('%s.mat', obj.FileName), 'ChSetup', 'AcqSetup');
            
            obj.fileCounter = 0;
            obj.byteCounter = 0;
            obj.fidData = fopen(obj.getBinaryFileName(), 'wb');
        end
        
        function AddTime(obj, time)
            StartTime = time; %#ok<NASGU>
            save(sprintf('%s.mat', obj.FileName), 'StartTime', '-append');
        end
        
        function AddData(obj, data)
            if size(data,2) == obj.nCh
                % write into bin file
                fwrite(obj.fidData, data', 'float32');
                obj.byteCounter = obj.byteCounter + numel(data)*32/8;
                
                % check if new file needs to be opened
                if obj.byteCounter > CStreamer.MaximalBinaryFileSize
                    % close previous
                    fclose(obj.fidData);
                    % update counters
                    obj.byteCounter = 0;
                    obj.fileCounter = obj.fileCounter + 1;
                    % open new file
                    obj.fidData = fopen(obj.getBinaryFileName(), 'wb');
                end
            else
                error('NiHuLab:CStreamer', 'Data dimension is incompatible with Channel Setup');
            end
        end
        
        function AddTwit(obj, twit)
            obj.Twits(end+1,:) = {toc(obj.tStart), twit};
        end
        
        function Finalize(obj, type)
            fclose(obj.fidData);
            EndTime = now; %#ok<NASGU>
            Twits = obj.Twits; %#ok<PROP,NASGU>
            save(sprintf('%s.mat', obj.FileName), 'EndTime', 'Twits', '-append');
            if nargin > 1
                switch type
                    case 'verbose'
                        msgbox(sprintf('Data successfully saved to file\n\n%s', obj.FileName), 'Success');
                end
            end
        end
    end % of public methods
    
    methods (Access = private)
        function fname = getBinaryFileName(obj)
            fname = sprintf('%s_%.5d.dat', obj.FileName, obj.fileCounter);
        end
    end % of private methods
end % of classdef
