function [H, D] = LoadStream(fname, TimeLim)
%LOADSTREAM Load stream saved by the NiHu.Lab Record module
% [H, D] = LoadStream(fname)
% [H, D] = LoadStream(fname, time_limits_in_sec)

[pathstr, name] = fileparts(fname);
H = load(fullfile(pathstr, sprintf('%s.mat', name)));
nCh = length(H.ChSetup);
datafiles = dir(sprintf('%s_*.dat', fullfile(pathstr, name)));
nFiles = length(datafiles);

% get segment size from first file
fn = fullfile(pathstr, datafiles(1).name);
N = size(read_segment(fn, nCh), 1);

if nargin == 1 % read total file
    % allocate space for data
    D = zeros(N*nFiles, nCh);
    
    % read file-by file
    s = 0;  % actual data size
    for iFile = 1 : nFiles
        fn = fullfile(pathstr, datafiles(iFile).name);
        d = read_segment(fn, nCh);
        D(s + (1:size(d,1)),:) = d;
        s = s + size(d,1);
    end
    D = D(1:s,:);
    
else % read a segment only
    % segment limits in samples
    nLim = floor(TimeLim * H.AcqSetup.Fs);
    D = zeros(diff(nLim), nCh); % preallocate
    s = 0;
    for iFile = floor(nLim(1)/N)+1 : floor(nLim(2)/N)+1
        fn = fullfile(pathstr, datafiles(iFile).name);
        % read total file
        d = read_segment(fn, nCh);
        nlim = min(max(nLim - (iFile-1)*N, 0), N-1);
        d = d(nlim(1)+1 : nlim(2), :);
        D(s+(1:size(d,1)), :) = d;
        s = s + size(d,1);
    end
end

end % of function LoadStream

function D = read_segment(fname, nCh)
fid = fopen(fname, 'rb');
D = fread(fid, [nCh, Inf], 'float32').';
fclose(fid);
end
