#include "nihu_daqmx.h"

#include <stdlib.h>

int measure(TaskHandle taskHandle)
{
	int32 err;
	float64 fs = 51200;
	float64 *readArray;
	int32 sampsPerChanRead;
	int32 sampsPerChanRequested = 40000;
	int nChan = 8;
	int i;

	readArray = (float64 *)malloc(nChan*sampsPerChanRequested*sizeof(float64));

	fs = 51200;
	err = DAQmxCfgSampClkTiming(taskHandle, NULL, fs, DAQmx_Val_Rising, DAQmx_Val_ContSamps,
		(uInt64)(2*fs*nChan));

	if ((err = DAQmxStartTask (taskHandle)) != 0) 
		printErrorMessage(stderr, err);
	printf("Task started successfully\n");

	for (i = 0; i < 10; ++i)
	{
		err = DAQmxReadAnalogF64(taskHandle,
			sampsPerChanRequested, DAQmx_Val_WaitInfinitely, DAQmx_Val_GroupByScanNumber,
			readArray, nChan*sampsPerChanRequested, &sampsPerChanRead, NULL);
		printf("%d samples read per channel.\n", sampsPerChanRead);
	}

	if ((err = DAQmxStopTask (taskHandle)) != 0) 
		printErrorMessage(stderr, err);
	printf("Task stopped successfully\n");

	free(readArray);

	return 0;
}

int runTask(TaskHandle taskHandle)
{
	int32 err;

	char const *deviceName = "cDAQ9184-19A3141";
	ChassisProperties chassisProperties;

	err = DAQmxReserveNetworkDevice(deviceName, 1);
	if (err == 0)
		printf("Device reserved successfully\n");
	else {
		printErrorMessage(stderr, err);
		return 1;
	}

	getChassisProperties(deviceName, &chassisProperties);
	printChassisProperties(stdout, &chassisProperties);

/*
	err = DAQmxCreateAIVoltageChan(taskHandle, chanName[0], NULL, DAQmx_Val_Cfg_Default, -5.0, +5.0, DAQmx_Val_Volts, NULL);
	if (err != 0) 
		printErrorMessage(err);
	printf("Channel added succesfully\n");

	err = DAQmxCreateAIVoltageChan(taskHandle, chanName[1], NULL, DAQmx_Val_Cfg_Default, -5.0, +5.0, DAQmx_Val_Volts, NULL);
	if (err != 0) 
		printErrorMessage(err);
	printf("Channel added succesfully\n");

	measure(taskHandle);
*/		

	err = DAQmxUnreserveNetworkDevice(deviceName);
	if (err != 0) {
		printErrorMessage(stderr, err);
		return 1;
	}
	else 
		printf("Device unreserved succesfully\n");

	return 0;
}

int main(void)
{
	TaskHandle taskHandle;
	int32 err;
	char const *taskName = "MyTask";

	if ((err = DAQmxCreateTask (taskName, &taskHandle)) != 0) 
	{
		printErrorMessage(stderr, err);
		return 1;
	}
	printf("Task \"%s\" created successfully\n", taskName);

	runTask(taskHandle);

	if ((err = DAQmxClearTask (taskHandle)) != 0) 
	{
		printErrorMessage(stderr, err);
		return 1;
	}
	printf("Task \"%s\" cleared successfully\n", taskName);

	return 0;
}

