/** \file nihu_daqmx.c
 * \author Peter Fiala
 * \brief Implementation file of NiHu DAQmx module
 */
#include "nihu_daqmx.h"

#include <string.h>

void printDeviceProperties(FILE *fp, DeviceProperties const *devProp)
{
	fprintf(fp, "Device Name: %s\n", devProp->deviceName);
	fprintf(fp, "Product Number: %X\n", devProp->productNumber);
	fprintf(fp, "Product Type: %s\n", devProp->productType);
	fprintf(fp, "Product Category: %X\n", devProp->productCategory);
	fprintf(fp, "Serial Number: %08X\n", devProp->serialNumber);
}

void printChassisProperties(FILE *fp, ChassisProperties const *chassProp)
{
	int i;
	printDeviceProperties(fp, &chassProp->chassisProperties);
	for (i = 0; i < chassProp->numModules; ++i)
	{
		fprintf(fp, "--------\n");
		printDeviceProperties(fp, chassProp->moduleDeviceProperties+i);
	}
}

int getDeviceProperties(char const *devName, DeviceProperties *deviceProperties)
{
	int32 err;
	
	err = DAQmxGetDevProductNum(devName, &(deviceProperties->productNumber));
	if (err != 0)
		return err;
	err = DAQmxGetDevProductType(devName, deviceProperties->productType, sizeof(deviceProperties->productType));
	if (err != 0)
		return err;
	err = DAQmxGetDevProductCategory(devName, &(deviceProperties->productCategory));
	if (err != 0)
		return err;

	err = DAQmxGetDevSerialNum(devName, &(deviceProperties->serialNumber));
	if (err != 0)
		return err;

	strcpy(deviceProperties->deviceName, devName);

	return 0;
}

int getChassisProperties(char const *devName, ChassisProperties *chassisProperties)
{
	int32 err;
	char moduleNames[1024], *start;
	int iMod = 0;

	chassisProperties->numModules = 0;
	err = getDeviceProperties(devName, &(chassisProperties->chassisProperties));
	if (err != 0)
		return err;

	err = DAQmxGetDevChassisModuleDevNames(devName, moduleNames, 1024);
	if (err != 0)
		return err;
	start = moduleNames;
	while (1)
	{
		char *stop = strchr(start, ',');
		if (stop != NULL) {
			*stop = '\0';
			stop++;
		}
		err = getDeviceProperties(start, &(chassisProperties->moduleDeviceProperties[iMod]));
		if (err != 0)
			return err;
		iMod++;
		if (stop == NULL)
			break;
		while (!isalpha(*stop) && *stop != '\0')
			++stop;
		start = stop;
	}

	chassisProperties->numModules = iMod;

	return 0;
}

void printErrorMessage(FILE *fp, int32 err)
{
	enum { MAX_ERROR = 1024 };
	char errorBuf[MAX_ERROR];
	DAQmxGetErrorString(err, errorBuf, MAX_ERROR);
	fprintf(fp, "NiDAQmx Error: %d: %s\n", err, errorBuf);
}

